@@ -276,3 +276,26 @@ class FlaviusPrintPackingLabel(FlaviusBase):
                                                        create_url=conf.FLAVIUS_API_PRINT_PACKING_LABEL,
                                                        update_url='',
                                                        delete_url='')
+
+
+class FlaviusHeaderSearch(FlaviusBase):
+    """
+    伝票検索用API
+    """
+    def __init__(self):
+        super(FlaviusHeaderSearch, self).__init__(search_url=conf.FLAVIUS_API_HEADER_SEARCH,
+                                                  create_url='',
+                                                  update_url='',
+                                                  delete_url='')
+
+
+class FlaviusHeaderSetTaxReduceWithDid(FlaviusBase):
+    """
+    軽減税率適用API
+    """
+    def __init__(self):
+        super(FlaviusHeaderSetTaxReduceWithDid, self).__init__(
+            search_url='',
+            create_url='',
+            update_url=conf.FLAVIUS_API_HEADER_SET_TAX_REDUCE_WITH_DID,
+            delete_url='')
