@@ -139,6 +139,14 @@ class Settings:
     def FLAVIUS_API_PRINT_PACKING_LABEL(self):
         return getattr(settings, "FLAVIUS_API_PRINT_PACKING_LABEL", 'api/print_packing_label.php')
 
+    @property
+    def FLAVIUS_API_HEADER_SEARCH(self):
+        return getattr(settings, "FLAVIUS_API_HEADER_SEARCH", 'api/header_search.php')
+
+    @property
+    def FLAVIUS_API_HEADER_SET_TAX_REDUCE_WITH_DID(self):
+        return getattr(settings, "FLAVIUS_API_HEADER_SET_TAX_REDUCE_WITH_DID", 'api/header_set_tax_reduce_with_did.php')
+
     @property
     def EXCLUDE_TAX(self):
         return getattr(settings, "EXCLUDE_TAX", '91100')
